#!/bin/sh
#*****************************************************************************
#
#	File:		XtoolsTypeManager.sh
#
#	Purpose:	This is the main ClearCase Type Manager shell script for Xtools
#			applications
#
#	Comments:	Mainly spawns a java process for handling merge situations
#			with Xtools artifacts.
#
#			See mgr_info.sh for supported command line arguments
#
#	Licensed Materials - Property of IBM
#	(C) Copyright IBM Corp. 2002, 2003.  All Rights Reserved.
#
#	US Government Users Restricted Rights - Use, duplication or disclosure
#	restricted by GSA ADP Schedule Contract with IBM Corp.
#
#******************************************************************************

# Get the install dir value
INSTALL_DIR="$(dirname $0)"

# Find Eclipse home directory
ECLIPSE_DIR="$INSTALL_DIR"
while [ ! -f "$ECLIPSE_DIR/eclipse/eclipse" ]
do
    PARENT_DIR="$(dirname $ECLIPSE_DIR)"
    if [ "$PARENT_DIR" = "$ECLIPSE_DIR" ]; then
        echo "ERROR: Failed to find eclipse home directory above type manager install directory \"$INSTALL_DIR\""
        exit 1
    fi
    ECLIPSE_DIR="$PARENT_DIR"
done
ECLIPSE_DIR="$ECLIPSE_DIR/eclipse"

# validate eclipse directory path
ECLIPSE_RUNTIME="$ECLIPSE_DIR/eclipse"
if [ ! -f $ECLIPSE_RUNTIME ]; then
	echo "ERROR: eclipse executable at \"$ECLIPSE_RUNTIME\" is not exists!"
	exit 1
fi

# Get the java executable path
# Assume jre is available under eclipse home
JAVA_RUNTIME="$ECLIPSE_DIR/jre/bin/java"

# validate java execute path
if [ ! -f $JAVA_RUNTIME ]; then
	echo "ERROR: Java executable at \"$JAVA_RUNTIME\" is not exists!"
	exit 1
fi

# Find swt.jar and its library directory under eclipse home
FILE_LIST=`find "$ECLIPSE_DIR" -name swt.jar`
for FILE_PATH in $FILE_LIST; do
    SWT_DIR="$(dirname $(dirname $(dirname $FILE_PATH)))"
    SO_FILE_LIST=`find "$SWT_DIR" -name libswt-*.so`
    for SO_FILE_PATH in $SO_FILE_LIST; do
	SWT_JAR_PATH="$FILE_PATH"
	SWT_SO_DIR="$(dirname $SO_FILE_PATH)"
	break 2
    done
done

# validate swt.jar file path
if [ ! -f $SWT_JAR_PATH ]; then
    echo "Fail to find swt.jar file under \"$ECLIPSE_DIR\""
    exit 1
fi

# validate swt library folder path
if [ ! -d $SWT_SO_DIR ]; then
    echo "Fail to find swt library directory under \"$ECLIPSE_DIR\""
    exit 1
fi


# Create Jar file list
FILE_LIST=`ls $INSTALL_DIR/*.jar`
JAR_LIST=""
for FILE_PATH in $FILE_LIST; do
    JAR_LIST="$JAR_LIST$FILE_PATH:"
done

# add swt jar files to jar list
FILE_PATH="$(dirname $SWT_JAR_PATH)"
FILE_LIST=`ls $FILE_PATH/*.jar`
for FILE_PATH in $FILE_LIST; do
    JAR_LIST="$JAR_LIST$FILE_PATH:"
done


# Get the classpath
CLASSPATH=" -classpath \"$INSTALL_DIR:$JAR_LIST:\""

# Get the main class
MAIN_CLASS=" com.ibm.xtools.comparemerge.typemanager.internal.TypeManagerOperation"

# Must set up libary path for os to find the swt static libraries
LD_LIBRARY_PATH="$SWT_SO_DIR:$ECLIPSE_DIR:$INSTALL_DIR:$LD_LIBRARY_PATH"
export LD_LIBRARY_PATH

# Get the vmargs for the jre
VMARGS=" -Djava.library.path=\"$LD_LIBRARY_PATH\""

# Get the command line arguments
COMMAND_LINE_ARGS="$(basename $0) "

IFS='\'
for param in $*; do
    COMMAND_LINE_ARGS="$COMMAND_LINE_ARGS \"$param\""
done

# get the current working directory
CWD="-cwd \"$PWD\""

# Compose the full command
COMMAND="$JAVA_RUNTIME $VMARGS $CLASSPATH $MAIN_CLASS $COMMAND_LINE_ARGS $CWD"

#echo "Launch Command=$COMMAND"

# Execute the command
eval $COMMAND

# Get the exit code of the command
status="$?"

# Exit the script with the exit code
exit $status
